#
# spec file for package ghc-invariant
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name invariant
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.6.4
Release:        1.2
Summary:        Haskell98 invariant functors
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-StateVar-devel
BuildRequires:  ghc-StateVar-prof
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bifunctors-devel
BuildRequires:  ghc-bifunctors-prof
BuildRequires:  ghc-comonad-devel
BuildRequires:  ghc-comonad-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-contravariant-devel
BuildRequires:  ghc-contravariant-prof
BuildRequires:  ghc-profunctors-devel
BuildRequires:  ghc-profunctors-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-stm-prof
BuildRequires:  ghc-tagged-devel
BuildRequires:  ghc-tagged-prof
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
BuildRequires:  ghc-th-abstraction-devel
BuildRequires:  ghc-th-abstraction-prof
BuildRequires:  ghc-transformers-compat-devel
BuildRequires:  ghc-transformers-compat-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-unordered-containers-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
%endif

%description
Haskell98 invariant functors (also known as exponential functors).

For more information, see Edward Kmett's article "Rotten Bananas":

<http://comonad.com/reader/2008/rotten-bananas/>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Dec  5 2024 Peter Simons <psimons@suse.com>
- Update invariant to version 0.6.4.
  [#] 0.6.4 [2024.12.05]
  * Drop support for pre-8.0 versions of GHC.
* Tue Mar 19 2024 Peter Simons <psimons@suse.com>
- Update invariant to version 0.6.3.
  [#] 0.6.3 [2024.03.19]
  * Support building with `template-haskell-2.22.*` (GHC 9.10).
* Sun Mar 17 2024 Peter Simons <psimons@suse.com>
- Update invariant to version 0.6.2 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Sep 30 2023 Peter Simons <psimons@suse.com>
- Update invariant to version 0.6.2 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Aug  6 2023 Peter Simons <psimons@suse.com>
- Update invariant to version 0.6.2.
  [#] 0.6.2 [2023.08.06]
  * The Template Haskell machinery now uses `TemplateHaskellQuotes` when
    building with GHC 8.0+ instead of manually constructing each Template Haskell
    `Name`. A consequence of this is that `invariant` will now build with GHC
    9.8, as `TemplateHaskellQuotes` abstracts over some internal Template Haskell
    changes introduced in 9.8.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Mon Feb 27 2023 Peter Simons <psimons@suse.com>
- Update invariant to version 0.6.1.
  [#] 0.6.1 [2023.02.27]
  * Support `th-abstraction-0.5.*`.
* Sat Jul 23 2022 Peter Simons <psimons@suse.com>
- Update invariant to version 0.6 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Jul  3 2022 Peter Simons <psimons@suse.com>
- Update invariant to version 0.6.
  [#] 0.6 [2022.07.03]
  * Loosen the `Monad` constraint in the `Invariant(2)` instances for
    `Kleisli` to an `Invariant` constraint.
  * Loosen the `Comonad` constraint in the `Invariant2` instance for `Cokleisli`
    to an `Invariant` constraint.
  * Add `Invariant` instances for `PastroSum`, `CopastroSum`, `Environment`,
    `FreeMapping`, `Pastro`, and `FreeTraversing` from the `profunctors` library.
  * Add `Invariant(2)` instances for `Copastro` and `Coyoneda` from the
    `profunctors` library.
* Sat May  7 2022 Peter Simons <psimons@suse.com>
- Update invariant to version 0.5.6.
  [#] 0.5.6 [2022.05.07]
  * Add `InvariantProfunctor` and `InvariantArrow` newtypes that admit
    implementations of `invmap` that only require `Profunctor` or `Arrow`
    constraints, respectively. Also add top-level `invmapProfunctor` and
    `invmapArrow` functions.
* Mon Nov  1 2021 psimons@suse.com
- Update invariant to version 0.5.5.
  [#] 0.5.5 [2021.11.01]
  * Allow building with GHC 9.2.
  * Allow building with `transformers-0.6.*`.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Oct  6 2020 psimons@suse.com
- Update invariant to version 0.5.4.
  [#] 0.5.4 [2020.10.01]
  * Fix a bug in which `deriveInvariant2` would fail on certain data types with
    three or parameters if the first two parameters had phantom roles.
  * Fix a bug in which `deriveInvariant(2)` would fail on sufficiently complex
    uses of rank-n types in constructor fields.
  * Fix a bug in which `deriveInvariant(2)` would needlessly reject data types
    whose two last type parameters appear as oversaturated arguments to a type
    family.
* Mon Aug 31 2020 psimons@suse.com
- Update invariant to version 0.5.3 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Fri May  3 2019 psimons@suse.com
- Update invariant to version 0.5.3.
  [#] 0.5.3 [2019.05.02]
  * Implement `foldMap'` in the `Foldable` instance for `WrappedFunctor` when
    building with `base-4.13` or later.
* Tue Apr 30 2019 psimons@suse.com
- Update invariant to version 0.5.2.
  [#] 0.5.2 [2019.04.26]
  * Support `th-abstraction-0.3.0.0` or later.
  * Only incur a `semigroups` dependency on old GHCs.
* Fri Dec 14 2018 Peter Simons <psimons@suse.com>
- Update Cabal build instructions for more accurate dependencies on
  th-abstraction.
* Thu Aug  2 2018 psimons@suse.com
- Add invariant at version 0.5.1.
